/***************************************************************************
 *                                                                         *
 *   KCPULoad and KNetLoad are copyright (c) 1999-2000, Markus Gustavsson  *
 *                                       (c) 2002, Ben Burton              *
 *                                       (c) 2004, Diego Pettenò           *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/
#include "loadapp.h"
#include "statpopup.h"
#include "settings.h"
#include "visualization.h"

#include <qtimer.h>
#include <qcheckbox.h>
#include <khelpmenu.h>
#include <kpopupmenu.h>
#include <kconfigdialog.h>
#include <kaction.h>
#include <kdebug.h>
#include <klocale.h>
#include <kiconloader.h>
#include <kglobal.h>

LoadApp::LoadApp(bool cansplit)
 : KApplication()
{
	// Prepare for actions, but don't actually add any actions.
	m_coll = new KActionCollection(this);
	
	// Set up a timer for our periodic updates.
	m_readTimer = new QTimer(this);
	connect(m_readTimer, SIGNAL(timeout()), this, SLOT(takeReading()));
	
	VisualizationConfig *viscfg = new VisualizationConfig(0, "Visualization");
	if ( ! cansplit )
		delete viscfg->kcfg_Split;

	m_cfgdialog = new KConfigDialog(0, "settings", Settings::self());
	m_cfgdialog->addPage(viscfg, i18n("Visualization"), "style");
	connect(m_cfgdialog, SIGNAL(settingsChanged()), this, SLOT(reloadSettings()));
}

LoadApp::~LoadApp()
{
}

void LoadApp::initPopupMenu(KPopupMenu *menu)
{
    m_actClearHistory->plug(menu);
    m_actSettings->plug(menu);
    menu->insertSeparator();

    menu->insertItem(SmallIcon("help"), i18n("&Help"),
        (new KHelpMenu(0, KGlobal::instance()->aboutData(), false))->menu());
}

void LoadApp::setupActions()
{
	m_actClearHistory = new KAction(i18n("&Clear"), "editdelete", 0,
		0, 0, m_coll, "clear");
	
	m_actSettings = new KAction(i18n("&Configure..."), "configure", 0,
		this, SLOT(showSettings()), m_coll, "settings");
}

void LoadApp::takeReading()
{
	kdDebug() << "LoadApp::takeReading() not redefind." << endl;
}

void LoadApp::showSettings()
{
	if(KConfigDialog::showDialog("settings"))
		return;
	
	m_cfgdialog->show();
}

void LoadApp::startUpdates()
{
	takeReading();
	m_readTimer->start(Settings::timeout());
}

void LoadApp::stopUpdates()
{
	m_readTimer->stop();
	m_popup->setText(i18n("Inactive."));
}

void LoadApp::reloadSettings()
{
	if (Settings::enabled())
		startUpdates();
	else
		stopUpdates();
}

#include "loadapp.moc"
