/***************************************************************************
 *                                                                         *
 *   KCPULoad and KNetLoad are copyright (c) 1999-2000, Markus Gustavsson  *
 *                                       (c) 2002, Ben Burton              *
 *                                       (c) 2004, Diego Pettenò           *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/
#ifndef LOADAPP_H
#define LOADAPP_H

#include <kapplication.h>

class QTimer;
class KAction;
class KActionCollection;
class KConfigDialog;
class KPopupMenu;
class StatPopup;

/**
 * @author Diego 'Flameeyes' Petteno
 * @brief K*Load application base class
 * 
 * This class will be used by KNetLoad and KCPULoad applications to provide
 * a base interface for both.
 * This class replaces the old StatPopup and derived classes, which mixed
 * application-dependant and widgets in one class.
 */
class LoadApp : public KApplication
{
Q_OBJECT
public:
	/**
	 * @brief Base constructor for K*Load applications
	 * @param cansplit If true, the application supports splitted graphs.
	 *        Should be true only for KCPULoad.
	 *
	 * This function takes care of create the config dialog, the timer
	 * and in general setting the common things for K*Load applications.
	 */
	LoadApp(bool cansplit = true);
	~LoadApp();
protected:
	QTimer *m_readTimer;
		///< Timer to read the values of loads
	KActionCollection* m_coll;
		///< The collection of all application-level actions.
	KConfigDialog *m_cfgdialog;
		///< Configuration dialog for the application.
	StatPopup *m_popup;
		///< Popup dialog which shows the current load
//@{
/**
 * @name actions Popup menus' actions
 */
	KAction* m_actClearHistory;
	KAction* m_actSettings;
//@}

	/**
	 * @brief Set up the collection of application-wide actions.
	 * 
	 * The global configuration will be read at this point to set the
	 * initial states of these actions.
	 */
	virtual void setupActions();
	
	/**
	 * @brief Set up a popup menu for an application's tray icon.
	 * @param menu Popup menu to initialize
	 */
	void initPopupMenu(KPopupMenu *menu);
	
	void startUpdates();
	void stopUpdates();

protected slots:
	/**
	 * @brief Takes regular readings of loads
	 *
	 * This slot is called by m_readTimer timer to take regular readings of
	 * the loads monitored by the application.
	 *
	 * @note Subclassess @b must redefine this function
	 */
	virtual void takeReading();

	/**
	 * @brief Show the settings dialog
	 *
	 * This slot is used to show the configuation dialog to the user.
	 */
	void showSettings();

	/**
	 * @brief Reloads the settings for the application
	 *
	 * @note Subclassess @b can redefine this function to reload the docks.
	 */
	virtual void reloadSettings();
};

#endif
